function result = OPG(f1,x,varargin)
% PURPOSE: Computes Hessian based on the outer product of gradients estimator
% -------------------------------------------------------
% Usage:  H = OPG(func,x,varargin)
% Where: func = function name which returns N by 1 vector (N is the number of obs.)
%        fval = func(x,varargin)
%           x = vector of parameters (k by 1)
%    varargin = optional arguments passed to the function
% -------------------------------------------------------
% RETURNS:
%           H = OPG hessian
% -------------------------------------------------------

%eps = 1e-8;

k = size(x,1);
fx = feval(f1,x,varargin{:}); %N by 1 vector
n = size(fx,1);
 
% Compute the stepsize (h)
%h = eps.^(1/3)*max(abs(x),1e-8); % eps is floating point accuracy
% the stepsizes chosen here are very arbitrary and somewhat tuned to be as
% small as possible without resulting in a zero change when the derivative
% is taken
h = abs(x)*1e-4;
% use a bigger stepsize if the parameter is already very small or very big
for i=1:k
    if (abs(x(i)) <= 1e-8)
        h(i) = abs(x(i))*1e-2;
    end;
    if (abs(x(i)) >= 1e8)
        h(i) = abs(x(i))*1e-1;
    end;
end;
%xh = x+h; 
%h = xh-x;    

ee = sparse(1:k,1:k,h,k,k); % create k by k sparse matrix with h along diagonal
 
% Compute forward step 
G = zeros(n,k); 
for i=1:k
   % g is difference in function evaluated at x +/-h, then normalized
   % so this is basically first derivative w.r.t. each parameter in the
   % vector of parameters
   g = (feval(f1,x+ee(:,i),varargin{:})-feval(f1,x-ee(:,i),varargin{:}))./(2*h(i));
   G(:,i) = g;
end %N by k

% by information equality Hessian is product of first derivative matrices
H = G'*G; % k by k
result =  H;