function premium = leaderpremium(ldrparam,popshare,P,lambda)

% This function calculates the leadership premium: the amount a leader gets
% as a leader minus what he gets when not leader.
%
% The assumption is that this premium is invariant to the leader and the
% identity of the other group used to calculate what the leader gets when
% not leader. Thus, it is calculated as the difference between what the
% largest group gets as leader and what the largest group gets when the
% second largest group is leader.
%
% Inputs:
%
%   popshare - population share for each ethnicity (of size = number of
%       ethnicities)
%   ldrparam - parameter vector
%       Fprime - leadership payoff, transformed
%       gamma_t - probability of successful coup, transformed
%       r - factor by which patronage is destroyed when a revolution occurs,
%           transformed
%   P - population size
%   lambda - fraction of elites

% number of ethnicities
numeth = size(popshare,1);

% extract parameters
Fprime = ldrparam(1);
gamma_t = ldrparam(2);
rprime = ldrparam(3);

% calculate gamma and F
gamma = abs(gamma_t)/(1+abs(gamma_t));
F = Fprime*(1-gamma)/gamma;

[splitter,corecoal,bigoutsiders] = splitgroup(popshare(1:numeth),rprime);

% calculate shares when largest is leader
% no check is done for valid shares as this function is assumed to be
% called with estimated parameters
[shareswhenleading,excl,flag,actualsplitter,actualsplitsize] = splitpredictedshares(F,gamma,rprime,splitter,corecoal,bigoutsiders,popshare,7,P,lambda);

% calculate shares when second largest is leader
[shareswhennotleading,excl,flag,actualsplitter,actualsplitsize] = splitpredictedshares(F,gamma,rprime,splitter,corecoal,bigoutsiders,popshare,1,P,lambda);

premium = shareswhenleading(7) - shareswhennotleading(7);