function result = numder(f1,x,varargin)
% PURPOSE: Computes numerical derivative of a function w.r.t the vector x
% -------------------------------------------------------
% Usage:  D = numder(func,x,varargin)
% Where: func = function name which returns scalar
%           x = vector of parameters (k by 1)
%    varargin = optional arguments passed to the function
% -------------------------------------------------------
% RETURNS:
%           D = numerical derivative as a column vector
% -------------------------------------------------------

eps = 1e-8;

k = size(x,1); % number of parameters

% Compute the stepsize (h)
% h = eps.^(1/3)*max(abs(x),1e-8); % eps is floating point accuracy
% xh = x+h; % a trick to get to power of 2
% h = xh-x;    

% instead of using Hiro's method, we need a small stepsize for the case
% that a parameter (rprime) is very close to the boundary of 0 or 1
h = 1e-2*abs(x);
ee = sparse(1:k,1:k,h,k,k); % create k by k sparse matrix with h along diagonal
 
% Compute forward step 
for i=1:k
   % d is difference in function evaluated at x +/-h, then normalized
   % so this is basically first derivative w.r.t. each parameter in the
   % vector of parameters
   d = (feval(f1,x+ee(:,i),varargin{:})-feval(f1,x-ee(:,i),varargin{:}))./(2*h(i));
   D(i) = d;
end %N by k

result =  D';