function lltotal = polarizationlikelihood(param,numcountries,polarization,popshare,govshare,countries,includeobs,vectorize)

% This function calculates the (negative) log likelihood of the model which
% calculates predicted shares using country-level polarization. The wrapper
% is used to calculate the likelihood across all countries (because some
% parameters are shared across countries).
%
% Inputs:
%
% param: this is the parameter vector to be estimated [polar xi] where
% polar is the coefficient on the country-level polarization term
%
% numcountries : number of countries
%
% polarization: country-level polarization factor
%
% popshare: vector of the population share for each ethnicity-time obs
%
% govshare: observed share of government positions for each ethnicity-time
% obs
%
% countries: 3-column array in which the first column is the number of
% ethnicities in the country and the second column is the observation at
% which the country starts in the data, the third is where the country ends
%
% includeobs : observations to be included in the likelihood
%
% numeth: number of ethnicities (assumed fixed over time), used to delineate
% time periods
%
% vectorize : set to 1 to return individual log-likelihoods instead of sum

lastdataobs = size(popshare,1);

if vectorize == 0
    ll = zeros(numcountries,1);
else
    ll = zeros(lastdataobs,1);
end;

for c=1:numcountries
    
    % country specific constants
    numeth = countries(c,1); % number of ethnicities
    firstobs = countries(c,2);
    lastobs = countries(c,3);
    
    % country parameters
    cparam(1) = param(1); % polar coef. (common to all)
    cparam(2) = param(c+1); % xi
    
    if vectorize == 0
        ll(c) = polarizationlikelihood(cparam,polarization(c),popshare(firstobs:lastobs),...
            govshare(firstobs:lastobs),includeobs(firstobs:lastobs),numeth,0);
    else
        ll(firstobs:lastobs) = polarizationlikelihood(cparam,polarization(c),popshare(firstobs:lastobs),...
            govshare(firstobs:lastobs),includeobs(firstobs:lastobs),numeth,1);
    end;
end;

if vectorize == 0
    lltotal = ones(numcountries,1)'*ll;
else
    lltotal = ll;
end;

