*do "C:/WORK/RT/FRT1_paper/FRT1_stata_code/FRT1_Data_Prep_1.do"
cd "C:/WORK/RT/data/"
set more off
***********************************************************************************
*FIGURES 1-4, TABLES 1-5
***********************************************************************************

* Fig. A1
use tmp1.dta, clear
twoway  (line unrepres Year, tlabel(1960m1(240)2004m1) cmiss(n)), by(countryname)
* Table A3 
gen Country=""
gen Mean=.
gen StDev=.
gen Obs=.
global n=1
foreach c of global country {
	qui sum unrepres if countryn=="`c'"
	replace Country="`c'" if _n==$n
	replace Mean=r(mean) if _n==$n
	replace StDev=r(sd) if _n==$n
	replace Obs=r(N) if _n==$n
	global n=$n+1
}
list Country Obs Mean StDev if _n<$n
****

* Fig.1a
* Load data
use ethnicgroup_data.dta, clear
keep if country=="Cameroon"
drop if ethnicg=="Other"
gen diff = govshare-popshare
gen leaderdiff = diff if leadergroup==1
gen noleaderdiff = diff if leadergroup==0
rename ethnicg Ethnicity
sort year month
rename year Year 
twoway (line leaderdiff Year, lpa(longdash) lw(thick) xlabel(1960(20)2000) yaxis(1) ylabel(-20 0 20) cmissing(n))/*
     */(line noleaderdiff Year, cmissing(n) xti("Share of Cabinet Seats - Pop. Share in Cameroon")) (spike leadertransition Year, yaxis(2) ylabel(none, axis(2))), legend(order(1 "If Leader Group" 2 "If Not Leader" 3 "Leader Transition")) by(Ethnicity)
****

* Fig.1b
* Load data
use ethnicgroup_data.dta, clear
keep if country=="Sierra Leone"
drop if ethnicg=="Other"
gen diff = govshare-popshare
gen leaderdiff = diff if leadergroup==1
gen noleaderdiff = diff if leadergroup==0
rename ethnicg Ethnicity
sort year month
rename year Year 
twoway (line leaderdiff Year, lpa(longdash) lw(thick) xlabel(1960(20)2000) yaxis(1) ylabel(-20 0 20) cmissing(n))/*
      */(line noleaderdiff Year, cmissing(n) xti("Share of Cabinet Seats - Pop. Share in Sierra Leone")) (spike leadertransition Year, yaxis(2) ylabel(none, axis(2))), legend(order(1 "If Leader Group" 2 "If Not Leader" 3 "Leader Transition")) by(Ethnicity)
****

* Table 1
* Note time coverage, missing years, years with two governments, and number of ethnic groups are done manually
use all_data_raw.dta, clear
gen Country=""
gen NumGov=.
gen NumLead=.
gen NumGovMin=.
gen GovSize=.
gen NumMin=.
gen AvTen=.
gen NumMissing=.
gen MissingFreq=.
bysort country lastname firstname (year_gov month_gov): gen tenure=_N if _n==_N
gen missing=(ethnicgroup=="Missing")
global n=1
foreach c of global country {
	replace Country="`c'" if _n==$n
	qui sum order if order==0&country=="`c'"
	replace NumGov=r(N) if _n==$n
	qui sum order if country=="`c'"
	replace NumGovMin=r(N) if _n==$n
	replace GovSize=NumGovMin/NumGov if _n==$n
	qui tab lastname if order==0&country=="tab `c'"
	replace NumLead=r(r) if _n==$n
	qui sum tenure if country=="`c'"
	replace AvTen=r(mean) if _n==$n
	replace NumMin=NumGovMin/AvTen if _n==$n
	qui sum missing if country=="`c'"
	replace MissingFreq=r(mean) if _n==$n
	replace NumMissing=MissingFreq*NumGovMin if _n==$n
	global n=$n+1
}
list Country NumGov NumLead NumGovMin GovSize NumMin AvTen NumMissing MissingFreq if _n<$n
****

* Table 2: Summary stats for full samples
use tmp3.dta, clear
sum govshare popshare leadergroup largestg coalitionm
****

* Table 3
* Is there a formateur advantage?
use tmp3, clear
xi: areg govshare popshare leadergroup i.year, cluster(country) absorb(country)
outreg using NT3, bdec(4) keep(popshare leadergroup _cons) se sq replace
xi: areg govshare popshare popshare2 leadergroup i.year, cluster(country) absorb(country)
outreg using NT3, bdec(4) keep(popshare popshare2 leadergroup _cons) se sq merge replace
xi: areg govshare popshare popshare2 i.year if leadergroup==0, cluster(country) absorb(country)
outreg using NT3, bdec(4) keep(popshare popshare2 _cons) se sq merge replace
* Top government positions only
*Uses president, prime minister, vice president, vice prime minister, defence, state, justice, finance, treasury, economy, industry, commerce, budget, agriculture.
xi: areg topgovshare popshare leadergroup i.year , cluster(country) absorb(country)
outreg using NT3, bdec(4) keep(popshare leadergroup _cons) se sq merge replace
xi: areg topgovshare popshare popshare2 leadergroup i.year , cluster(country) absorb(country)
outreg using NT3, bdec(4) keep(popshare popshare2 leadergroup _cons) se sq merge replace
xi: areg topgovshare popshare popshare2 i.year if leadergroup==0, cluster(country) absorb(country)
outreg using NT3, bdec(4) keep(popshare popshare2 _cons) se sq merge replace

****
* Alternative Top Post definition. Addendum to Table 3
*Uses president, prime minister, vice president, vice prime minister, defence, state, justice.
use tmp3_alt_top, clear
* Top government positions only
xi: areg topgovshare popshare leadergroup i.year , cluster(country) absorb(country)
outreg using NT3at, bdec(4) keep(popshare leadergroup _cons) se sq replace
xi: areg topgovshare popshare popshare2 leadergroup i.year , cluster(country) absorb(country)
outreg using NT3at, bdec(4) keep(popshare popshare2 leadergroup _cons) se sq merge replace
xi: areg topgovshare popshare popshare2 i.year if leadergroup==0, cluster(country) absorb(country)
outreg using NT3at, bdec(4) keep(popshare popshare2 _cons) se sq merge replace
* Alternative Popshare definitions. Addendum to Table 3
use tmp3, clear
bysort ethnicgroup year: egen mpopshare = mean(popshare)
gen mpopshare2=mpopshare^2
xi: areg govshare mpopshare leadergroup i.year, cluster(country) absorb(country)
outreg using NT3m, bdec(4) keep(mpopshare leadergroup _cons) se sq replace
xi: areg govshare mpopshare mpopshare2 leadergroup i.year, cluster(country) absorb(country)
outreg using NT3m, bdec(4) keep(mpopshare mpopshare2 leadergroup _cons) se sq merge replace
xi: areg govshare mpopshare mpopshare2 i.year if leadergroup==0, cluster(country) absorb(country)
outreg using NT3m, bdec(4) keep(mpopshare mpopshare2 _cons) se sq merge replace
drop mpopshare*
bysort ethnicgroup year: egen mpopshare = max(popshare)
gen mpopshare2=mpopshare^2
xi: areg govshare mpopshare leadergroup i.year, cluster(country) absorb(country)
outreg using NT3m, bdec(4) keep(mpopshare leadergroup _cons) se sq merge replace
xi: areg govshare mpopshare mpopshare2 leadergroup i.year, cluster(country) absorb(country)
outreg using NT3m, bdec(4) keep(mpopshare mpopshare2 leadergroup _cons) se sq merge replace
xi: areg govshare mpopshare mpopshare2 i.year if leadergroup==0, cluster(country) absorb(country)
outreg using NT3m, bdec(4) keep(mpopshare mpopshare2 _cons) se sq merge replace
****

* Fig. 2
* Basic nonlinearity
use tmp3, clear
sort govshare
drop if leadergroup==1
twoway (scatter govshare popshare, msize(vtiny) msy(o) yaxis(1) yti("Ethnic Group's Cabinet Share") xti("Ethnic Group's Population Share")) /*
*/(lowess govshare popshare, bw(.8) lwi(med) yaxis(1))/*
*/(lfit govshare popshare, lwi(med) lpa(dot) yaxis(1))/*
*/(line govshare govshare, lpa(longdash) lwi(med))/*
*/ , aspectratio(1) ysize(7) legend(order(1 "Share of Posts to Non-leader Groups" 2 "Nonparametric Fit (Lowess)" 3 "Linear Fit" 4 "45 Degree Line") row(4))
****

* Fig. A6
* Benchmark Posts USA
use US_ethnicgroup_data.dta, clear
gen diff = govshare-popshare
gen leaderdiff = diff if leadergroup==1
gen noleaderdiff = diff if leadergroup==0
rename ethnicg Ethnicity
sort year
rename year Year 
twoway (line leaderdiff Year, lpa(longdash) lw(thick) xlabel(1960(20)2000) yaxis(1) ylabel(-20 0 20) cmissing(n))/*
     */(line noleaderdiff Year, cmissing(n) xti("Share of Cabinet Seats - Pop. Share in USA")) (spike leadertransition Year, yaxis(2) ylabel(none, axis(2))), legend(order(1 "If Leader Group" 2 "If Not Leader" 3 "Leader Transition")) by(Ethnicity)
****

* Fig. A1 for Online Appendix
* Load data
global a = 1
use ethnicgroup_data.dta, clear
foreach country in "Benin" "Cameroon" "Cote d'Ivoire" "CongoKinshasa" "Gabon" "Ghana" "Guinea" "Kenya" "Liberia" "Nigeria" "Republic of Congo" "Sierra Leone" "Tanzania" "Togo" "Uganda" {
preserve
keep if country=="`country'"
drop if ethnicg=="Other"
gen diff = govshare-popshare
gen leaderdiff = diff if leadergroup==1
gen noleaderdiff = diff if leadergroup==0
rename ethnicg Ethnicity
sort year month
rename year Year 
twoway (line leaderdiff Year, lpa(longdash) lw(thick) xlabel(1960(20)2000) yaxis(1) ylabel(-20 0 20) cmissing(n))/*
     */(line noleaderdiff Year, cmissing(n) xti("Share of Cabinet Seats - Pop. Share in `country'")) (spike leadertransition Year, yaxis(2) ylabel(none, axis(2))), legend(order(1 "If Leader Group" 2 "If Not Leader" 3 "Leader Transition")) by(Ethnicity)

graph save FIGA1_$a, replace
global a = $a+1
restore
}	 
****
